==> owncloud-app-contacts-2%3A1.3.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/ru.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Контакты",
    "Address book name" : "Название адресной книги",
    "No contacts in here" : "Здесь нет контактов",
    "Name" : "Наименование контакта",
    "Organization" : "Организация",
    "Title" : "Заголовок",
    "Add field ..." : "Добавить поле ...",
    "Import" : "Импорт",
    "Add contact" : "Добавить контакт",
    "No search result for {query}" : "По запросу {query} ничего не найдено",
    "All contacts" : "Все контакты",
    "Not grouped" : "Без группы",
    "Post Office Box" : "Почтовый ящик",
    "Postal Code" : "Почтовый индекс",
    "City" : "Город",
    "State or province" : "Область или район",
    "Country" : "Страна",
    "Address" : "Адрес",
    "(new group)" : "(новая группа)",
    "New contact" : "Новый контакт",
    "{addressbook} shared by {owner}" : "{addressbook} поделился {owner}",
    "No contacts in file. Only VCard files are allowed." : "Нет контактов в файле. Только VCard файлы разрешены.",
    "Nickname" : "Псевдоним",
    "Notes" : "Заметки",
    "Website" : "Сайт",
    "Federated Cloud ID" : "ID в объединении облачных хранилищ",
    "Home" : "Главная",
    "Work" : "Рабочий",
    "Other" : "Другой",
    "Groups" : "Группы",
    "Birthday" : "День рождения",
    "Email" : "Эл. почта",
    "Instant messaging" : "Мессенджер",
    "Phone" : "Телефон",
    "Mobile" : "Мобильный",
    "Fax" : "Факс",
    "Fax home" : "Домашний факс",
    "Fax work" : "Факс работы",
    "Pager" : "Пейджер",
    "Voice" : "Голосовая почта",
    "Social Network" : "Социальная сеть",
    "Settings" : "Настройки"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> owncloud-app-contacts-2%3A1.3.1.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/ru.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Контакты",
    "Address book name" : "Название адресной книги",
    "Import" : "Импорт",
    "The selected image is too big (max 1MB)" : "Выбранное изображение слишком велико (макс. 1 МБ)",
    "No contacts in here" : "Здесь нет контактов",
    "Name" : "Наименование контакта",
    "Organization" : "Организация",
    "Title" : "Должность",
    "Add field ..." : "Добавить поле ...",
    "Add contact" : "Добавить контакт",
    "No search result for {query}" : "По запросу {query} ничего не найдено",
    "All contacts" : "Все контакты",
    "Not grouped" : "Без группы",
    "Post Office Box" : "Почтовый ящик",
    "Postal Code" : "Почтовый индекс",
    "City" : "Город",
    "State or province" : "Область или район",
    "Country" : "Страна",
    "Address" : "Адрес",
    "(new group)" : "(новая группа)",
    "New contact" : "Новый контакт",
    "{addressbook} shared by {owner}" : "{addressbook} поделился {owner}",
    "No contacts in file. Only VCard files are allowed." : "В файле нет контактов. Допустимы только файлы VCard.",
    "Nickname" : "Псевдоним",
    "Notes" : "Заметки",
    "Website" : "Сайт",
    "Federated Cloud ID" : "ID в объединении облачных хранилищ",
    "Home" : "Домашний",
    "Work" : "Рабочий",
    "Other" : "Другой",
    "Groups" : "Группы",
    "Birthday" : "День рождения",
    "Email" : "Эл. почта",
    "Instant messaging" : "Мессенджер",
    "Phone" : "Телефон",
    "Mobile" : "Мобильный",
    "Fax" : "Факс",
    "Fax home" : "Домашний факс",
    "Fax work" : "Факс работы",
    "Pager" : "Пейджер",
    "Voice" : "Голосовая почта",
    "Social Network" : "Социальная сеть",
    "Settings" : "Настройки"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
